import { TokenType } from "./TokenType";
export declare class Token {
    private type;
    private value;
    private line;
    private column;
    /**
     * @constructor
     * @param {TokenType} type The type of the token
     * @param {*} value The value of the token
     * @param {number} line The line where the token is located in the source
     * @param {number} column The column where the token is located in the source
     */
    constructor(type: TokenType, value: any, line: number, column: number);
    /**
     * Tests the current token for a type and/or a content.
     *
     * @param {TokenType} type
     * @param {string|string[]|number} values
     * @returns {boolean}
     */
    test(type: TokenType, values?: string | string[] | number): boolean;
    /**
     * Return the line where the token is located in the source.
     *
     * @return {number}
     */
    getLine(): number;
    /**
     * Return the column where the token is located in the source.
     *
     * @return {number}
     */
    getColumn(): number;
    /**
     * Return the type of the token.
     *
     * @return {TokenType}
     */
    getType(): TokenType;
    /**
     * Return the value of the token.
     *
     * @return {*}
     */
    getValue(): any;
    /**
     * Return the human-readable representation of the token.
     *
     * @return {string}
     */
    toString(): string;
    /**
     * Serialize the token to a Twig source.
     *
     * @return {string}
     */
    serialize(): string;
}
